@@ -8,14 +8,12 @@
 
   SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
-#ifndef CALENDARVIEWS_TODOVIEW_H
-#define CALENDARVIEWS_TODOVIEW_H
+#pragma once
 
 #include "eventview.h"
 #include <Akonadi/Calendar/ETMCalendar>
 #include <Akonadi/Calendar/IncidenceChanger>
 
-#include <KConfig>
 #include <QPointer>
 
 class KJob;
@@ -40,7 +38,7 @@ class QMenu;
 class QModelIndex;
 class QToolButton;
 class QTimer;
-
+class KConfig;
 namespace EventViews
 {
 /**
@@ -105,7 +103,7 @@ protected Q_SLOTS:
     void resizeEvent(QResizeEvent *) override;
     void addQuickTodo(Qt::KeyboardModifiers modifier);
 
-    void contextMenu(const QPoint &pos);
+    void contextMenu(QPoint pos);
 
     void selectionChanged(const QItemSelection &selected, const QItemSelection &deselected);
 
@@ -115,13 +113,13 @@ protected Q_SLOTS:
     void deleteTodo();
     void newTodo();
     void newSubTodo();
-    void copyTodoToDate(const QDate &date);
+    void copyTodoToDate(QDate date);
 
 private Q_SLOTS:
     void scheduleResizeColumns();
     void resizeColumns();
     void itemDoubleClicked(const QModelIndex &index);
-    void setNewDate(const QDate &date);
+    void setNewDate(QDate date);
     void setNewPercentage(QAction *action);
     void setNewPriority(QAction *action);
     void changedCategories(QAction *action);
@@ -181,4 +179,3 @@ private:
 };
 }
 
-#endif
